@@ -23,21 +23,23 @@ const EXTENSION_ID = 'ipylab:plugin';
 const extension: JupyterFrontEndPlugin<void> = {
   id: EXTENSION_ID,
   autoStart: true,
-  requires: [IJupyterWidgetRegistry, ILabShell],
-  optional: [ICommandPalette],
+  requires: [IJupyterWidgetRegistry],
+  optional: [ICommandPalette, ILabShell],
   activate: (
     app: JupyterFrontEnd,
     registry: IJupyterWidgetRegistry,
-    shell: ILabShell,
-    palette: ICommandPalette
+    palette: ICommandPalette,
+    labShell: ILabShell | null
   ): void => {
     // add globals
     widgetExports.JupyterFrontEndModel.app = app;
-    widgetExports.ShellModel.shell = shell;
+    widgetExports.ShellModel.shell = app.shell;
+    widgetExports.ShellModel.labShell = labShell;
     widgetExports.CommandRegistryModel.commands = app.commands;
     widgetExports.CommandPaletteModel.palette = palette;
     widgetExports.SessionManagerModel.sessions = app.serviceManager.sessions;
-    widgetExports.SessionManagerModel.shell = shell;
+    widgetExports.SessionManagerModel.shell = app.shell;
+    widgetExports.SessionManagerModel.labShell = labShell;
 
     registry.registerWidget({
       name: MODULE_NAME,
