@@ -1,7 +1,7 @@
 // Copyright (c) ipylab contributors
 // Distributed under the terms of the Modified BSD License.
 
-import { ILabShell } from '@jupyterlab/application';
+import { JupyterFrontEnd, ILabShell } from '@jupyterlab/application';
 
 import { DOMUtils } from '@jupyterlab/apputils';
 
@@ -42,6 +42,8 @@ export class ShellModel extends WidgetModel {
    */
   initialize(attributes: any, options: any): void {
     this._shell = ShellModel.shell;
+    this._labShell = ShellModel.labShell;
+
     super.initialize(attributes, options);
     this.on('msg:custom', this._onMessage.bind(this));
 
@@ -60,38 +62,41 @@ export class ShellModel extends WidgetModel {
     const model = await unpack_models(serializedWidget, this.widget_manager);
     const view = await this.widget_manager.create_view(model, {});
     const title = await unpack_models(model.get('title'), this.widget_manager);
-    const pWidget = view.pWidget;
+    const luminoWidget = view.luminoWidget;
 
-    pWidget.id = id ?? DOMUtils.createDomID();
+    luminoWidget.id = id ?? DOMUtils.createDomID();
 
-    MessageLoop.installMessageHook(pWidget, (handler: any, msg: Message) => {
-      switch (msg.type) {
-        case 'close-request': {
-          const widgets = this.get('_widgets').slice();
-          ArrayExt.removeAllWhere(widgets, (w: any) => w.id === handler.id);
-          this.set('_widgets', widgets);
-          this.save_changes();
-          break;
+    MessageLoop.installMessageHook(
+      luminoWidget,
+      (handler: any, msg: Message) => {
+        switch (msg.type) {
+          case 'close-request': {
+            const widgets = this.get('_widgets').slice();
+            ArrayExt.removeAllWhere(widgets, (w: any) => w.id === handler.id);
+            this.set('_widgets', widgets);
+            this.save_changes();
+            break;
+          }
         }
+        return true;
       }
-      return true;
-    });
+    );
 
     const updateTitle = (): void => {
-      pWidget.title.label = title.get('label');
-      pWidget.title.iconClass = title.get('icon_class');
-      pWidget.title.closable = title.get('closable');
+      luminoWidget.title.label = title.get('label');
+      luminoWidget.title.iconClass = title.get('icon_class');
+      luminoWidget.title.closable = title.get('closable');
     };
 
     title.on('change', updateTitle);
     updateTitle();
 
-    if (area === 'left' || area === 'right') {
+    if ((area === 'left' || area === 'right') && this._labShell) {
       let handler;
       if (area === 'left') {
-        handler = this._shell['_leftHandler'];
+        handler = this._labShell['_leftHandler'];
       } else {
-        handler = this._shell['_rightHandler'];
+        handler = this._labShell['_rightHandler'];
       }
 
       // handle tab closed event
@@ -99,11 +104,11 @@ export class ShellModel extends WidgetModel {
         tab.title.owner.close();
       });
 
-      pWidget.addClass('jp-SideAreaWidget');
+      luminoWidget.addClass('jp-SideAreaWidget');
     }
 
-    this._shell.add(pWidget, area, args);
-    return pWidget.id;
+    this._shell.add(luminoWidget, area, args);
+    return luminoWidget.id;
   }
 
   /**
@@ -128,11 +133,15 @@ export class ShellModel extends WidgetModel {
         break;
       }
       case 'expandLeft': {
-        this._shell.expandLeft();
+        if (this._labShell) {
+          this._labShell.expandLeft();
+        }
         break;
       }
       case 'expandRight': {
-        this._shell.expandRight();
+        if (this._labShell) {
+          this._labShell.expandRight();
+        }
         break;
       }
       default:
@@ -151,7 +160,9 @@ export class ShellModel extends WidgetModel {
   static view_module: string = null;
   static view_module_version = MODULE_VERSION;
 
-  private _shell: ILabShell;
+  private _shell: JupyterFrontEnd.IShell;
+  private _labShell: ILabShell;
 
-  static shell: ILabShell;
+  static shell: JupyterFrontEnd.IShell;
+  static labShell: ILabShell;
 }
